\name{beta.bar}
\alias{beta.bar}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Compute the estimates of betas. }
\description{
  This function is used internally to compute the estimates of betas.
}
\usage{
beta.bar(x)
}

\arguments{
  \item{x}{ A matrix or numeric data.frame consisting of an n (no. of items) by N
  (no. of methods) matrix of measuremnts. }
}
\details{
See Jaech, p. 184.
}
\value{
 A vector of length N (no. of methods) containing the estimates of beta.
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick }

\seealso{ \code{\link{cb.pd}}, \code{\link{ncb.od}},\code{\link{lrt}} }
\examples{

data(pm2.5)
beta.bar(pm2.5) # estimate betas (accuracy parameter)

}

\keyword{ htest }

\eof
\name{cb.pd}
\alias{cb.pd}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Compute accuracy estimates and maximum likelihood estimates of precision for the
constant bias measurement error model using paired data. }
\description{
Compute accuracy estimates and maximum likelihood estimates of precision for the
constant bias measurement error model using paired data.
}
\usage{
cb.pd(x, conf.level = 0.95, M = 40)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ n (no. of items) x N (no. of methods) matrix or data.frame containing the measurements. N must be greater than 3 and n > N.}
  \item{conf.level}{ Chosen onfidence level. }
  \item{M}{ Maximum no.of iterations to reach convergence. }
}
\details{
Measurement Error Model:
  
x[i,k] = alpha[i] + beta[i]*mu[k] + epsilon[i,k]
 
where x[i,k] is the measurement by the ith method for the kth item, i = 1 to N,
k = 1 to n, mu[k] is the true value for the kth item, epsilon[i,k] is the
Normally distributed random error with variance sigma[i] squared for the ith method and the kth item, and
alpha[i] and beta[i] are the accuracy parameters for the ith method.

The imprecision for the ith method is sigma[i]. If all alphas are zeroes and all betas are ones, there is
no bias. If all betas equal 1, then there is a constant bias. Otherwise there is a nonconstant bias.

ME (method of moments estimator) and MLE are the same for N=3 instruments
 except for a factor of (n-1)/n: MLE = (n-1)/n * ME

Using paired differences forces Constant Bias model (beta[1] = beta[2] = ... = beta[N]). Also,
the process variance CANNOT be estimated.
}
\value{
  \item{conf.level }{Confidence level used.}
  \item{sigma.table }{Table of accuracy and precision estimates and confidence
  intervals.}
  \item{n.items }{No. of items.}
  \item{N.methods }{No. of methods}
  \item{Grubbs.initial.sigma2 }{N vector of initial imprecision estimates using Grubbs' method}
  \item{sigma2 }{N vector of variances that measure the method imprecision.}
  \item{sigma2.se2 }{N vector of squared standard errors of the estimated imprecisions (variances).}
  \item{alpha.cb }{N vector of estimated alphas for constant bias model.}
  \item{alpha.ncb }{N vector of estimated alphas for nonconstant bias model}
  \item{beta }{N vector of hypothesized betas for the constant bias model - all ones.}
  \item{df }{N vector of estimated degrees of freedom.}
  \item{chisq.low }{N vector of chi-square values for the lower tail (used to compute the ci upper bound).}
  \item{chisq.low }{N vector of chi-square values for the upper tail (used to compute the ci lower bound).}
  \item{lb }{N vector of lower bounds for confidence intervals}
  \item{ub }{N vector of upper bounds for confidence intervals}
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net }

\seealso{ \code{\link{ncb.od}},
 \code{\link{lrt}}
 }
\examples{

data(pm2.5)
cb.pd(pm2.5)

}
\keyword{ htest }


\eof
\name{errors.cb}
\alias{errors.cb}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Extracts the estimated measurement errors assuming there is a constant bias and using the original data. }
\description{
  Extracts the estimated measurement errors assuming there is a constant bias and using the original data values.
}
\usage{
errors.cb(x)
}
\arguments{
  \item{x}{ A matrix or numeric data.frame consisting of an n (no. of items) by N
  (no. of methods) matrix of measuremnts. N must be greater than 3 and n > N. }
}
\details{
Errors should have a zero mean and should be Normally distributed with constant variance for a given method.

}
\value{
  \item{errors.cb }{ n x N matrix of estimated measurement errors. }
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley

. }
\author{ Richard A. Bilonick rab@nauticom.net }

\seealso{ \code{\link{cb.pd}}, \code{\link{ncb.od}},\code{\link{lrt}} }
\examples{

data(pm2.5)
errors.cb(pm2.5)

}

\keyword{ htest }


\eof
\name{errors.nb}
\alias{errors.nb}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Extracts the estimated measurement errors assuming there is no bias and using the original data. }
\description{
  Extracts the estimated measurement errors assuming there is no bias and using the original data
  values.
}
\usage{
errors.nb(x)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ A matrix or numeric data.frame consisting of an n (no. of items) by N
  (no. of methods) matrix of measuremnts. N must be greater than 3 and n > N. }
}
\details{
Errors should have a zero mean and should be Normally distributed with constant variance for a given method.

}
\value{

  \item{errors.nb }{n x N matrix of estimated errors.}
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{Richard A. Bilonick rab@nauticom.net }

\seealso{ \code{\link{cb.pd}}, \code{\link{ncb.od}},\code{\link{lrt}} }
\examples{

data(pm2.5)
errors.nb(pm2.5)

}
\keyword{ htest }

\eof
\name{errors.ncb}
\alias{errors.ncb}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Extracts the estimated measurement errors assuming there is a
nonconstant bias and using the original data values. }
\description{

Extracts the estimated measurement errors assuming there is a
nonconstant bias and using the original data values.  
}
\usage{
errors.ncb(x)
}

\arguments{
  \item{x}{  A matrix or numeric data.frame consisting of an n (no. of items) by N
  (no. of methods) matrix of measuremnts. N must be greater than 3 and n > N. }
}
\details{
Errors should have a zero mean and should be Normally distributed with constant variance for a given method.
}
\value{  
\item{errors.ncb }{n x N matrix of estimated errors.}
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net }

\seealso{ \code{\link{cb.pd}}, \code{\link{ncb.od}},\code{\link{lrt}} }
\examples{

data(pm2.5)
errors.ncb(pm2.5)

}

\keyword{ htest }

\eof
\name{lrt}
\alias{lrt}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Likelihood ratio test for all betas equalling one. }
\description{
  Likelihood ratio test statistic - H0: all betas = one.
}
\usage{
lrt(x, M = 40)
}

\arguments{
  \item{x}{ n (no. of items) x N (no. of methods) matrix or data.frame containing the measurements. N must be greater than 3 and n > N.}
  \item{M}{ Maximum no. of iterations for convergence. }
}
\details{
See Jaech, pp. 204-205.
}
\value{
  \item{n.items }{No.of items.}
  \item{N.methods }{No. of methods.'}
  \item{beta.bars }{N vector of estimated betas.}
  \item{lambda }{Chi-square test statistic.}
  \item{df }{Degrees of freedom for the test (N-1).'}
  \item{p.value }{Empirical significance level for the observed test statistic.'}
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net }

\seealso{ \code{\link{ncb.od}},\code{\link{cb.pd}},\code{\link{pm2.5}} }
\examples{

data(pm2.5)

lrt(pm2.5) # compare all 5 samplers (4 personal and 1 frm)

lrt(pm2.5[,1:4]) # compare only the personal samplers

stem(lrt(pm2.5)$beta.bars) # examine the estimated betas

}
\keyword{ htest }

\eof
\name{mle}
\alias{mle}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Compute maximum likelihood estimates of precision. }
\description{
  This is an internal function that computes the maximum likelihood estimates of precision for the constant
  bias model using paired data.
}
\usage{
mle(v, r, ni)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{v}{ Variance-Covariance matrix for the n x N items by methods measurement data. }
  \item{r}{ Initial estimates of imprecision, usually Grubbs. }
  \item{ni}{ No. of items measured. }
}

\value{
An N vector containing the maximum likelihood estimates of precision.
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net}

\keyword{ htest }

\eof
\name{mle.se2}
\alias{mle.se2}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Compute squared standard errors for imprecision estimates for the
constant bias model using paired data. }
\description{
  This is an internal function that computes squared standard errors for imprecision estimates of the
constant bias model using paired data.
}
\usage{
mle.se2(v, r, ni)
}

\arguments{
  \item{v}{ Variance-Covariance matrix for the n x N items by methods measurement data. }
  \item{r}{ Initial estimates of imprecision, usually Grubbs }
  \item{ni}{ No. of items measured }
}
\details{
Computes the squared standard errors for the squared precisions. Before calling this function, compute the MLE's
}
\value{
  An N+1 symmetric H matrix. See p. 201 of Jaech, 1985, eq. 6.4.2.
}
\references{ J. L. Jaech, Statistical Analysis of Measurement Errors, Wiley, New
York: 1985. }
\author{ Richard A. Bilonick rab@nauticom.net }

\keyword{ htest }

\eof
\name{ncb.od}
\alias{ncb.od}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Compute accuracy estimates and maximum likelihood estimates of precision for the
nonconstant bias measurement error model using original data. }
\description{
 Compute accuracy estimates and maximum likelihood estimates of precision for the
nonconstant bias measurement error model using original data.
}
\usage{
ncb.od(x, beta = beta.bar(x), M = 40, conf.level = 0.95)
}
\arguments{
  \item{x}{ n (no. of items) x N (no. of methods) matrix or data.frame containing the measurements. N must be greater than 3 and n > N. }
  \item{beta}{ N vector of betas, either estimated by \code{beta.bar} function or hypothesized. }
  \item{M}{ Maximum no. of iterations for convergence. }
  \item{conf.level}{ Chosen confidence level. }
}
\details{
Measurement Error Model:
  
x[i,k] = alpha[i] + beta[i]*mu[k] + epsilon[i,k]
 
where x[i,k] is the measurement by the ith method for the kth item, i = 1 to N,
k = 1 to n, mu[k] is the true value for the kth item, epsilon[i,k] is the
Normally distributed random error with variance sigma[i] squared for the ith method and the kth item, and
alpha[i] and beta[i] are the accuracy parameters for the ith method.

The imprecision for the ith method is sigma[i]. If all alphas are zeroes and all betas are ones, there is
no bias. If all betas equal 1, then there is a constant bias. Otherwise there is a nonconstant bias.

By using the original data values, the betas can be estimated and also the process variance.
  
}
\value{
  \item{conf.level }{Confidence level used.}
  \item{sigma.table }{Table of accuracy and precision estimates and confidence
  intervals.}
  \item{n.items }{No. of items.}
  \item{N.methods }{No. of methods}
  \item{sigma2 }{N vector of variances that measure the method imprecision.}
  \item{alpha.cb }{N vector of estimated alphas for constant bias model.}
  \item{alpha.ncb }{N vector of estimated alphas for nonconstant bias model.}
  \item{beta }{N vector of estimated or hypothesized betas.}
  \item{df }{N vector of estimated degrees of freedom.}
  \item{lb }{N vector of lower bounds for confidence intervals.}
  \item{ub }{N vector of upper bounds for confidence intervals.}
  \item{H }{N+1 symmetric H matrix (see p. 201, Jaech).}
  \item{errors.nb }{n x N matrix of estimated measurement errors for no bias model.}
  \item{errors.cb }{n x N matrix of estimated measurement errors for constant bias model.}
  \item{errors.ncb }{n x N matrix of estimated measurement errors for nonconstant bias model}
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net }

\seealso{ \code{\link{cb.pd}},\code{\link{lrt}} }
\examples{

data(pm2.5)
ncb.od(pm2.5)               # nonconstant bias model using original data values
ncb.od(pm2.5,beta=rep(1,5)) # constant bias model using original data values

}

\keyword{ htest }

\eof
\name{pm2.5}
\alias{pm2.5}
\docType{data}
\title{ PM 2.5 Concentrations from SCAMP Collocated Samplers}
\description{
  Five filter-based samplers for measuring PM 2.5 concentrations were collocated and
  provided 77 complete sets of concentrations. This data was collected by the
  Stuebenville Comprehensive Air Monitoring Program (SCAMP) to check the accuracy and
  precision of the instruments.
}
\usage{data(pm2.5)}
\format{
  A data frame with 77 sets of PM 2.5 concentrations (micrograms per cubic meter) from the following 5 samplers:
  \describe{
    \item{ms.conc.1}{- personal sampler 1 - filter MS}
    \item{ws.conc.1}{- personal sampler 1 - filter WS}
    \item{ms.conc.2}{- personal sampler 2 - filter MS}
    \item{ws.conc.2}{- personal sampler 2 - filter WS}
    \item{frm}{- Federal Reference Method sampler}
  }
}
\source{
 Stuebenville Comprehensive Air Monitoring Program (SCAMP) 
}
\examples{
data(pm2.5)
boxplot(pm2.5)

# estimates of accuracy and precision
#   for nonconstant bias model using 
#   original data values
ncb.od(pm2.5)
}
\keyword{ datasets }


\eof
\name{precision.grubbs.cb.pd}
\alias{precision.grubbs.cb.pd}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Computes Grubbs' method of moments estimators of precision for the
constant bias model using paired differences. }
\description{
This is an internal function that computes Grubbs' method of moments estimators of precision for the
constant bias model using paired differences 
}
\usage{
precision.grubbs.cb.pd(x)
}
\arguments{
  \item{x}{ A matrix or numeric data.frame consisting of an n (no. of items) by N
  (no. of methods) matrix of measuremnts. N must be greater than 3 and n > N. }
}
\details{
See Jaech 1985, Chapters 3 & 4, p. 144 in particular.
}
\value{
Estimated squared imprecision estimates (variances).
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley.}
\author{ Richard A. Bilonick rab@nauticom.net}
 
\seealso{ \code{\link{precision.grubbs.ncb.od}}, \code{\link{ncb.od}}, \code{\link{cb.pd}},\code{\link{lrt}} }

\keyword{ htest }

\eof
\name{precision.grubbs.ncb.od}
\alias{precision.grubbs.ncb.od}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{  Computes Grubbs' method of moments estimators of precision for the
nonconstant bias model using original data values. }
\description{
This is an internal function that computes Grubbs' method of moments estimators of precision for the
nonconstant bias model using original data values.
}
\usage{
precision.grubbs.ncb.od(x, beta.bar.x = beta.bar(x))
}

\arguments{
  \item{x}{ A matrix or numeric data.frame consisting of an n (no. of items) by N
  (no. of methods) matrix of measuremnts. N must be greater than 3 and n > N. }
  \item{beta.bar.x}{ Either estimates of beta or hypothesized values (one for
  each method in an N vector). }
}
\details{
See Jaech, p. 184.
}
\value{
Grubbs' method of moments estimates of the squared imprecision (variances).
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net }
 
\seealso{\code{\link{precision.grubbs.cb.pd}}, \code{\link{ncb.od}}, \code{\link{cb.pd}},\code{\link{lrt}} }

\keyword{ htest }

\eof
\name{precision.mle.ncb.od}
\alias{precision.mle.ncb.od}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Computes iterative approximation to mle precision estimates for nonconstant bias model using original data. }
\description{
  This is an internal function that computes iterative approximation to mle precision estimates for nonconstant bias model using original data.
}
\usage{
precision.mle.ncb.od(x, M = 20, beta.bars = beta.bar(x), jaech.errors = FALSE)
}

\arguments{
  \item{x}{ A matrix or numeric data.frame consisting of an n (no. of items) by N (no. of methods) matrix of measuremnts. N must be greater than 3 and n > N. }
  \item{M}{ Maximum no. of iterations for convergence. }
  \item{beta.bars}{ Estimates or hypothesized values for the betas. }
  \item{jaech.errors}{ TRUE replicates the minor error in Jaech's Fortran code to allow comparison with his
  examples. }
}
\details{

Provides iterative approximation to MLE precision estimates for NonConstant Bias model using Original Data. See Jaech, p. 185-186.
 
}
\value{

  \item{sigma2 }{Estimated squared imprecisions (variances) for methods.}
  \item{sigma.mu2 }{Estimated process variance.}
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net}

\seealso{ \code{\link{precision.grubbs.ncb.od}},\code{\link{precision.grubbs.cb.pd}} }

\keyword{ htest }

\eof
\name{process.var.mle}
\alias{process.var.mle}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Compute process variance. }
\description{
  This is an internal function to compute the process variance.
}
\usage{
process.var.mle(sigma2, s, beta.bars, N, n)
}

\arguments{
  \item{sigma2}{ Estimated imprecisions for each method in an N vector. }
  \item{s}{ Variance-covariance N x N matrix. }
  \item{beta.bars}{ Estimates or hypothesized values for the N betas. }
  \item{N}{ No. of methods. }
  \item{n}{ No. of items. }
}
\details{
See Jaech p. 186  equations 6.37 - 6.3.10.
}
\value{

Estimated process variance.

}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net}

\keyword{ htest }


\eof
\name{process.var.mle.jaech.err}
\alias{process.var.mle.jaech.err}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Compute process variance but with minor error in Jaech Fortran code. }
\description{
This is an internal function to compute the process variance that replicates the minor
error in Jaech's Fortran code. This allows comparing merror estimates to those
shown in Jaech 1985.
}
\usage{
process.var.mle.jaech.err(sigma2, s, beta.bars, N, n)
}

\arguments{
  \item{sigma2}{ Estimated imprecisions for each method in an N vector. }
  \item{s}{ Variance-covariance N x N matrix. }
  \item{beta.bars}{ Estimates or hypothesized values for the N betas }
  \item{N}{ No. of methods. }
  \item{n}{ No. of items. }
}
\details{
See Jaech p. 186  equations 6.37 - 6.3.10.
Jaech p. 288 line 2330 has s[i,j] instead of s[j,j].
Jaech p. 288 line 2410 omits "- 1/d2".  

}
\value{

Estimated process variance but replicating minor error in Jaech's Fortran code.
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net }

\keyword{ htest }

\eof
\name{sigma.mle}
\alias{sigma.mle}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Computes the ith iteration for computing the
  squared imprecision estimates. }
\description{
  This is an internal function that computes the ith iteration for computing the
  squared imprecision estimates.
}
\usage{
sigma.mle(i, s, sigma2, sigma.mu2, beta.bars, N, n)
}

\arguments{
  \item{i}{ Iteration i. }
  \item{s}{ Variance-covariance N x N matrix. }
  \item{sigma2}{ Estimated imprecisions for each method in an N vector }
  \item{sigma.mu2}{ Estimated process varinace. }
  \item{beta.bars}{ Estimates or hypothesized values for the N betas. }
  \item{N}{ No. of methods. }
  \item{n}{ No. of items. }
}
\details{
See Jaech p. 185-186 equations 6.3.1 - 6.3.6.
}
\value{
Estimated squared imprecisions (variances) for the ith iteration.
}
\references{ Jaech, J. L. (1985) \emph{Statistical Analysis of Measurement Errors}. New York: Wiley. }
\author{ Richard A. Bilonick rab@nauticom.net }

\keyword{ htest }

\eof
